package sun.net;

import java.net.URL;
import java.util.Iterator;
import java.util.ArrayList;

public class ProgressMonitor
{
    private static ProgressMeteringPolicy meteringPolicy;
    private static ProgressMonitor pm;
    private ArrayList<ProgressSource> progressSourceList;
    private ArrayList<ProgressListener> progressListenerList;
    
    public ProgressMonitor() {
        this.progressSourceList = new ArrayList();
        this.progressListenerList = new ArrayList();
    }
    
    public static synchronized ProgressMonitor getDefault() {
        return ProgressMonitor.pm;
    }
    
    public static synchronized void setDefault(ProgressMonitor pm) {
        if (pm != null) {
            ProgressMonitor.pm = pm;
        }
    }
    
    public static synchronized void setMeteringPolicy(ProgressMeteringPolicy meteringPolicy) {
        if (meteringPolicy != null) {
            ProgressMonitor.meteringPolicy = meteringPolicy;
        }
    }
    
    public ArrayList<ProgressSource> getProgressSources() {
        ArrayList<E> list = new ArrayList();
        try {
            synchronized (this.progressSourceList) {
                Iterator<ProgressSource> iterator = this.progressSourceList.iterator();
                while (iterator.hasNext()) {
                    list.add((E)((ProgressSource)iterator.next()).clone());
                }
            }
        }
        catch (CloneNotSupportedException ex) {
            ex.printStackTrace();
        }
        return list;
    }
    
    public synchronized int getProgressUpdateThreshold() {
        return ProgressMonitor.meteringPolicy.getProgressUpdateThreshold();
    }
    
    public boolean shouldMeterInput(URL url, String s) {
        return ProgressMonitor.meteringPolicy.shouldMeterInput(url, s);
    }
    
    public void registerSource(ProgressSource progressSource) {
        synchronized (this.progressSourceList) {
            if (this.progressSourceList.contains(progressSource)) {
                return;
            }
            this.progressSourceList.add(progressSource);
        }
        if (this.progressListenerList.size() > 0) {
            ArrayList<Object> list = new ArrayList();
            synchronized (this.progressListenerList) {
                Iterator<ProgressListener> iterator = this.progressListenerList.iterator();
                while (iterator.hasNext()) {
                    list.add(iterator.next());
                }
            }
            Iterator<Object> iterator2 = list.iterator();
            while (iterator2.hasNext()) {
                ((ProgressListener)iterator2.next()).progressStart(new ProgressEvent(progressSource, progressSource.getURL(), progressSource.getMethod(), progressSource.getContentType(), progressSource.getState(), progressSource.getProgress(), progressSource.getExpected()));
            }
        }
    }
    
    public void unregisterSource(ProgressSource progressSource) {
        synchronized (this.progressSourceList) {
            if (!this.progressSourceList.contains(progressSource)) {
                return;
            }
            progressSource.close();
            this.progressSourceList.remove(progressSource);
        }
        if (this.progressListenerList.size() > 0) {
            ArrayList<Object> list = new ArrayList();
            synchronized (this.progressListenerList) {
                Iterator<ProgressListener> iterator = this.progressListenerList.iterator();
                while (iterator.hasNext()) {
                    list.add(iterator.next());
                }
            }
            Iterator<Object> iterator2 = list.iterator();
            while (iterator2.hasNext()) {
                ((ProgressListener)iterator2.next()).progressFinish(new ProgressEvent(progressSource, progressSource.getURL(), progressSource.getMethod(), progressSource.getContentType(), progressSource.getState(), progressSource.getProgress(), progressSource.getExpected()));
            }
        }
    }
    
    public void updateProgress(ProgressSource o) {
        synchronized (this.progressSourceList) {
            if (!this.progressSourceList.contains(o)) {
                return;
            }
        }
        if (this.progressListenerList.size() > 0) {
            ArrayList<Object> list = new ArrayList();
            synchronized (this.progressListenerList) {
                Iterator<ProgressListener> iterator = this.progressListenerList.iterator();
                while (iterator.hasNext()) {
                    list.add(iterator.next());
                }
            }
            Iterator<Object> iterator2 = list.iterator();
            while (iterator2.hasNext()) {
                ((ProgressListener)iterator2.next()).progressUpdate(new ProgressEvent(o, o.getURL(), o.getMethod(), o.getContentType(), o.getState(), o.getProgress(), o.getExpected()));
            }
        }
    }
    
    public void addProgressListener(ProgressListener e) {
        synchronized (this.progressListenerList) {
            this.progressListenerList.add(e);
        }
    }
    
    public void removeProgressListener(ProgressListener o) {
        synchronized (this.progressListenerList) {
            this.progressListenerList.remove(o);
        }
    }
    
    static {
        ProgressMonitor.meteringPolicy = new DefaultProgressMeteringPolicy();
        ProgressMonitor.pm = new ProgressMonitor();
    }
}
